@@ -1,6 +1,6 @@
 // Low-level functions for atomic operations: PA-RISC version  -*- C++ -*-
 
-// Copyright (C) 2002, 2004 Free Software Foundation, Inc.
+// Copyright (C) 2002, 2004, 2005 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -28,10 +28,10 @@
 // the GNU General Public License.
 
 #include <bits/c++config.h>
-#include <bits/atomicity.h>
+#include <ext/atomicity.h>
+
+_GLIBCXX_BEGIN_NAMESPACE(__gnu_cxx)
 
-namespace __gnu_cxx
-{
   template<int _Inst>
     struct _Atomicity_lock
     {
@@ -92,4 +92,5 @@ namespace __gnu_cxx
     __asm__ __volatile__ ("stw %1,0(%0)"
 			  : : "r" (&lock), "r" (tmp) : "memory");
   }
-} // namespace __gnu_cxx
+
+_GLIBCXX_END_NAMESPACE
