@@ -37,8 +37,8 @@
 #include <ostream>
 #include <ext/stdio_sync_filebuf.h>
 
-namespace std
-{
+_GLIBCXX_BEGIN_NAMESPACE(std)
+
   // string related to iostreams
   template 
     basic_istream<char>& 
@@ -66,14 +66,16 @@ namespace std
     basic_istream<wchar_t>& 
     getline(basic_istream<wchar_t>&, wstring&);
 #endif
-} // namespace std
 
-namespace __gnu_cxx
-{
+_GLIBCXX_END_NAMESPACE
+
+_GLIBCXX_BEGIN_NAMESPACE(__gnu_cxx)
+
   template class stdio_sync_filebuf<char>;
 #ifdef _GLIBCXX_USE_WCHAR_T
   template class stdio_sync_filebuf<wchar_t>;
 #endif
-} // namespace __gnu_cxx
+
+_GLIBCXX_END_NAMESPACE
 
 
