@@ -15,14 +15,14 @@
 
 // You should have received a copy of the GNU General Public License along
 // with this library; see the file COPYING.  If not, write to the Free
-// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 // USA.
 
 #include <ext/stdio_sync_filebuf.h>
 #include <testsuite_hooks.h>
 
 // libstdc++/12048
-void test05()
+void test04()
 {
   bool test __attribute__((unused)) = true;
   const char* name = "cin_unget-1.txt";
@@ -33,7 +33,7 @@ void test05()
   VERIFY( sbuf.sgetn(buf, 2) == 2 );
   std::wint_t c2 = sbuf.sungetc();
   VERIFY( c2 != WEOF );
-  std::wint_t c3 = std::fgetwc(file);
+  std::wint_t c3 = sbuf.sbumpc();
   VERIFY( c3 == std::char_traits<wchar_t>::to_int_type(buf[1]) );
 
   std::fclose(file);
@@ -41,6 +41,6 @@ void test05()
 
 int main ()
 {
-  test05();
+  test04();
   return 0;
 }
